==> icinga2_2.4.1.orig.tar.gz: icinga2-2.4.1/lib/hello/helloapplication.cpp <==
/******************************************************************************
 * Icinga 2                                                                   *
 * Copyright (C) 2012-2015 Icinga Development Team (http://www.icinga.org)    *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License                *
 * as published by the Free Software Foundation; either version 2             *
 * of the License, or (at your option) any later version.                     *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program; if not, write to the Free Software Foundation     *
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ******************************************************************************/

#include "hello/helloapplication.hpp"
#include "hello/helloapplication.tcpp"
#include "base/initialize.hpp"
#include "base/logger.hpp"
#include "base/scriptglobal.hpp"

using namespace icinga;

REGISTER_TYPE(HelloApplication);

INITIALIZE_ONCE(&HelloApplication::StaticInitialize);

void HelloApplication::StaticInitialize(void)
{
	ScriptGlobal::Set("ApplicationType", "HelloApplication");
}

/**
 * The entry point for the hello application.
 *
 * @returns An exit status.
 */
int HelloApplication::Main(void)
{
	Log(LogInformation, "HelloApplication", "Hello World!");

	return 0;
}

==> icinga2_2.6.0.orig.tar.gz: icinga2-2.6.0/lib/hello/helloapplication.cpp <==
/******************************************************************************
 * Icinga 2                                                                   *
 * Copyright (C) 2012-2016 Icinga Development Team (https://www.icinga.org/)  *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License                *
 * as published by the Free Software Foundation; either version 2             *
 * of the License, or (at your option) any later version.                     *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program; if not, write to the Free Software Foundation     *
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ******************************************************************************/

#include "hello/helloapplication.hpp"
#include "hello/helloapplication.tcpp"
#include "base/initialize.hpp"
#include "base/logger.hpp"
#include "base/scriptglobal.hpp"

using namespace icinga;

REGISTER_TYPE(HelloApplication);

INITIALIZE_ONCE([]() {
	ScriptGlobal::Set("ApplicationType", "HelloApplication");
});

/**
 * The entry point for the hello application.
 *
 * @returns An exit status.
 */
int HelloApplication::Main(void)
{
	Log(LogInformation, "HelloApplication", "Hello World!");

	return 0;
}
